@@ -87,7 +87,7 @@ class Hoe
   include Rake::DSL if defined?(Rake::DSL)
 
   # duh
-  VERSION = "4.0.2"
+  VERSION = "4.2.2"
 
   @@plugins = [:clean, :debug, :deps, :flay, :flog, :newb, :package,
                :publish, :gemcutter, :signing, :test]
@@ -458,7 +458,7 @@ class Hoe
   #  Call it multiple times if you are releasing under multiple licenses.
   #
   def license name
-    self.licenses << name
+    self.licenses << name.to_s
   end
 
   ##
@@ -675,12 +675,15 @@ class Hoe
                .chunk { |l| l[/^(?:=+|#+)/] || "" }
                .map(&:last)
                .each_slice(2)
-               .map { |k, v|
-                  kp = k.join
-                  kp = kp.strip.chomp(":").split.last.downcase if k.size == 1
-                  [kp, v.join.strip]
-                }
-               .to_h
+               .to_h { |k, v|
+                 raise "No body for %p section" % [k[0].strip] \
+                   unless v
+                 kp = k.map { |s|
+                   s.strip.chomp(":").sub(/(?:=+|#+)\s*/, '').downcase
+                 }.join("\n")
+
+                 [kp, v.join.strip]
+               }
 
     unless readme.empty? then
       desc     = readme.values_at(*description_sections).join("\n\n")
@@ -908,7 +911,7 @@ class Hoe
     end
   end
 
-  def skip_intuit_values?
+  def skip_intuit_values? # :nodoc:
     %w[summary description homepage].all? { |field| send field }
   end
 
@@ -932,7 +935,7 @@ class Hoe
     yield config, rc
   end
 
-  def maybe_load_yaml path
+  def maybe_load_yaml path # :nodoc:
     if File.exist? path then
       if YAML.respond_to? :safe_load_file then
         YAML.safe_load_file path, permitted_classes: [Regexp, Symbol]
@@ -945,7 +948,7 @@ class Hoe
   end
 end
 
-class File
+class File # :nodoc:
   # Like File::read, but strips out a BOM marker if it exists.
   def self.read_utf path
     r19 = "<3".respond_to? :encoding
@@ -960,7 +963,3 @@ class File
     end
   end
 end
-
-def Gem.bin_wrapper name # :nodoc: HACK
-  File.join Gem.bindir, Gem.default_exec_format % name
-end unless Gem.respond_to? :bin_wrapper
